netapp_ontap.models.windows_to_unix API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.windows_to_unix`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class WindowsToUnixSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the WindowsToUnix object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `attribute: str GET POST PATCH`

    Attribute name used to retrieve the UNIX account information for a Windows user account.

    Example: windowsAccount

  `no_domain_prefix: bool GET POST PATCH`

    Indicates whether or not the name for Windows to UNIX name mapping should have a domain prefix.

    Example: false

  `object_class: str GET POST PATCH`

    Name used to represent the windowsToUnix object class.

    Example: User